@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 # This file is part of beets.
 # Copyright 2016, Adrian Sampson.
 #
@@ -18,6 +19,7 @@ from __future__ import division, absolute_import, print_function
 
 import json
 import re
+import six
 from datetime import datetime, timedelta
 
 from requests_oauthlib import OAuth1Session
@@ -42,15 +44,15 @@ class BeatportAPIError(Exception):
 class BeatportObject(object):
     def __init__(self, data):
         self.beatport_id = data['id']
-        self.name = unicode(data['name'])
+        self.name = six.text_type(data['name'])
         if 'releaseDate' in data:
             self.release_date = datetime.strptime(data['releaseDate'],
                                                   '%Y-%m-%d')
         if 'artists' in data:
-            self.artists = [(x['id'], unicode(x['name']))
+            self.artists = [(x['id'], six.text_type(x['name']))
                             for x in data['artists']]
         if 'genres' in data:
-            self.genres = [unicode(x['name'])
+            self.genres = [six.text_type(x['name'])
                            for x in data['genres']]
 
 
@@ -159,7 +161,8 @@ class BeatportClient(object):
         :returns:               Tracks in the matching release
         :rtype:                 list of :py:class:`BeatportTrack`
         """
-        response = self._get('/catalog/3/tracks', releaseId=beatport_id)
+        response = self._get('/catalog/3/tracks', releaseId=beatport_id,
+                             perPage=100)
         return [BeatportTrack(t) for t in response]
 
     def get_track(self, beatport_id):
@@ -188,7 +191,7 @@ class BeatportClient(object):
             response = self.api.get(self._make_url(endpoint), params=kwargs)
         except Exception as e:
             raise BeatportAPIError("Error connecting to Beatport API: {}"
-                                   .format(e.message))
+                                   .format(e))
         if not response:
             raise BeatportAPIError(
                 "Error {0.status_code} for '{0.request.path_url}"
@@ -196,8 +199,9 @@ class BeatportClient(object):
         return response.json()['results']
 
 
+@six.python_2_unicode_compatible
 class BeatportRelease(BeatportObject):
-    def __unicode__(self):
+    def __str__(self):
         if len(self.artists) < 4:
             artist_str = ", ".join(x[1] for x in self.artists)
         else:
@@ -209,7 +213,7 @@ class BeatportRelease(BeatportObject):
         )
 
     def __repr__(self):
-        return unicode(self).encode('utf8')
+        return six.text_type(self).encode('utf-8')
 
     def __init__(self, data):
         BeatportObject.__init__(self, data)
@@ -224,21 +228,22 @@ class BeatportRelease(BeatportObject):
                 data['slug'], data['id'])
 
 
+@six.python_2_unicode_compatible
 class BeatportTrack(BeatportObject):
-    def __unicode__(self):
+    def __str__(self):
         artist_str = ", ".join(x[1] for x in self.artists)
         return (u"<BeatportTrack: {0} - {1} ({2})>"
                 .format(artist_str, self.name, self.mix_name))
 
     def __repr__(self):
-        return unicode(self).encode('utf8')
+        return six.text_type(self).encode('utf-8')
 
     def __init__(self, data):
         BeatportObject.__init__(self, data)
         if 'title' in data:
-            self.title = unicode(data['title'])
+            self.title = six.text_type(data['title'])
         if 'mixName' in data:
-            self.mix_name = unicode(data['mixName'])
+            self.mix_name = six.text_type(data['mixName'])
         self.length = timedelta(milliseconds=data.get('lengthMs', 0) or 0)
         if not self.length:
             try:
@@ -249,6 +254,7 @@ class BeatportTrack(BeatportObject):
         if 'slug' in data:
             self.url = "http://beatport.com/track/{0}/{1}".format(data['slug'],
                                                                   data['id'])
+        self.track_number = data.get('trackNumber')
 
 
 class BeatportPlugin(BeetsPlugin):
@@ -266,8 +272,8 @@ class BeatportPlugin(BeetsPlugin):
         self.register_listener('import_begin', self.setup)
 
     def setup(self, session=None):
-        c_key = self.config['apikey'].get(unicode)
-        c_secret = self.config['apisecret'].get(unicode)
+        c_key = self.config['apikey'].as_str()
+        c_secret = self.config['apisecret'].as_str()
 
         # Get the OAuth token from a file or log in.
         try:
@@ -388,10 +394,10 @@ class BeatportPlugin(BeetsPlugin):
         # cause a query to return no results, even if they match the artist or
         # album title. Use `re.UNICODE` flag to avoid stripping non-english
         # word characters.
-        query = re.sub(r'\W+', ' ', query, re.UNICODE)
+        query = re.sub(r'\W+', ' ', query, flags=re.UNICODE)
         # Strip medium information from query, Things like "CD1" and "disk 1"
         # can also negate an otherwise positive result.
-        query = re.sub(r'\b(CD|disc)\s*\d+', '', query, re.I)
+        query = re.sub(r'\b(CD|disc)\s*\d+', '', query, flags=re.I)
         albums = [self._get_album_info(x)
                   for x in self.client.search(query)]
         return albums
@@ -403,8 +409,7 @@ class BeatportPlugin(BeetsPlugin):
         artist, artist_id = self._get_artist(release.artists)
         if va:
             artist = u"Various Artists"
-        tracks = [self._get_track_info(x, index=idx)
-                  for idx, x in enumerate(release.tracks, 1)]
+        tracks = [self._get_track_info(x) for x in release.tracks]
 
         return AlbumInfo(album=release.name, album_id=release.beatport_id,
                          artist=artist, artist_id=artist_id, tracks=tracks,
@@ -416,7 +421,7 @@ class BeatportPlugin(BeetsPlugin):
                          catalognum=release.catalog_number, media=u'Digital',
                          data_source=u'Beatport', data_url=release.url)
 
-    def _get_track_info(self, track, index=None):
+    def _get_track_info(self, track):
         """Returns a TrackInfo object for a Beatport Track object.
         """
         title = track.name
@@ -424,10 +429,10 @@ class BeatportPlugin(BeetsPlugin):
             title += u" ({0})".format(track.mix_name)
         artist, artist_id = self._get_artist(track.artists)
         length = track.length.total_seconds()
-
         return TrackInfo(title=title, track_id=track.beatport_id,
                          artist=artist, artist_id=artist_id,
-                         length=length, index=index,
+                         length=length, index=track.track_number,
+                         medium_index=track.track_number,
                          data_source=u'Beatport', data_url=track.url)
 
     def _get_artist(self, artists):
