@@ -23,8 +23,9 @@ import os
 import shutil
 import tempfile
 import plistlib
-import urllib
-from urlparse import urlparse
+
+import six
+from six.moves.urllib.parse import urlparse, unquote
 from time import mktime
 
 from beets import util
@@ -57,7 +58,7 @@ def _norm_itunes_path(path):
     # E.g., '\\G:\\Music\\bar' needs to be stripped to 'G:\\Music\\bar'
 
     return util.bytestring_path(os.path.normpath(
-        urllib.unquote(urlparse(path).path)).lstrip('\\')).lower()
+        unquote(urlparse(path).path)).lstrip('\\')).lower()
 
 
 class Itunes(MetaSource):
@@ -84,7 +85,11 @@ class Itunes(MetaSource):
             self._log.debug(
                 u'loading iTunes library from {0}'.format(library_path))
             with create_temporary_copy(library_path) as library_copy:
-                raw_library = plistlib.readPlist(library_copy)
+                if six.PY2:
+                    raw_library = plistlib.readPlist(library_copy)
+                else:
+                    with open(library_copy, 'rb') as library_copy_f:
+                        raw_library = plistlib.load(library_copy_f)
         except IOError as e:
             raise ConfigValueError(u'invalid iTunes library: ' + e.strerror)
         except Exception:
